summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetemessage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetemessage.cpp')
-rw-r--r--kopete/libkopete/kopetemessage.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kopetemessage.cpp b/kopete/libkopete/kopetemessage.cpp
index c094ba72..a70b137b 100644
--- a/kopete/libkopete/kopetemessage.cpp
+++ b/kopete/libkopete/kopetemessage.cpp
@@ -43,7 +43,7 @@
using namespace Kopete;
class Message::Private
- : public KShared
+ : public TDEShared
{
public:
Private( const TQDateTime &timeStamp, const Contact *from, const ContactPtrList &to,
@@ -145,7 +145,7 @@ Message::~Message()
void Message::detach()
{
// there is no detach in KSharedPtr :(
if( d.count() == 1 )
return;
@@ -145,7 +145,7 @@ Message::~Message()
void Message::detach()
{
- // there is no detach in KSharedPtr :(
+ // there is no detach in TDESharedPtr :(
if( d.count() == 1 )
return;